@@ -133,7 +133,9 @@ tasklist_task_get_label (TasklistTask *task, int width, gboolean add_groupcount)
 
 	if (das_string == NULL)
 		das_string = _("???");
-
+	else if (strlen(das_string) > 512)
+		das_string = g_strndup(das_string, 512);
+		
 	label_len = gdk_string_width (tasklist->area->style->font, das_string);
 
 	overhead = tasklist->config.show_mini_icons ? 30 : 6;
@@ -640,22 +642,23 @@ real_layout_tasklist (gpointer data)
 	d(g_message ("Layout!"));
 
 	if (!tasklist->vtasks) {
-		d(g_message ("no tasks :(\n"));
-		gtk_widget_draw (tasklist->area, NULL);
-		return FALSE;
-	}
-
-	num = g_slist_length (tasklist->vtasks);
+		num = 0;
+	} else 
+		num = g_slist_length (tasklist->vtasks);
 	
 	switch (applet_widget_get_panel_orient (APPLET_WIDGET (tasklist->applet))) {
 	case ORIENT_UP:
 	case ORIENT_DOWN:
 		if (num == 0) {
-			if (tasklist->config.horz_fixed)
+			if (tasklist->config.horz_fixed) {
 				tasklist->horz_width = tasklist->config.horz_width;
+				if (tasklist->config.horz_never_push)
+					clamp_size (tasklist, &tasklist->horz_width);
+				tasklist->horz_width -= DRAG_HANDLE_SIZE;
+			}
 			else
-				tasklist->horz_width = 4;
-
+				tasklist->horz_width = 0;
+				
 			tasklist_change_size (tasklist, FALSE, -1);
 			
 			gtk_widget_draw (tasklist->area, NULL);
@@ -680,15 +683,20 @@ real_layout_tasklist (gpointer data)
 		}
 		
 		if (tasklist->config.horz_fixed) {
+			int width = tasklist->config.horz_width;
+			if (tasklist->config.horz_never_push)
+				clamp_size (tasklist, &width);
+			width -= DRAG_HANDLE_SIZE;
 			curheight = (ROW_HEIGHT * get_horz_rows(tasklist) - (tasklist->config.sunken?4:0)) / num_rows;
-			curwidth = (tasklist->config.horz_width - (tasklist->config.sunken?4:0)) / num_cols;
+			curwidth = (width - (tasklist->config.sunken?4:0)) / num_cols;
 
 		} else {
 			int width;
 
 			width = tasklist->config.horz_taskwidth * num_cols + DRAG_HANDLE_SIZE;
 
-			if (width > tasklist->config.horz_width)
+			if (width > tasklist->config.horz_width &&
+			    !tasklist->config.horz_never_push)
 				width = tasklist->config.horz_width;
 			
 			if (tasklist->config.horz_never_push)
@@ -738,10 +746,14 @@ real_layout_tasklist (gpointer data)
 			}
 		}
 
-		if (tasklist->config.horz_fixed)
+		if (tasklist->config.horz_fixed) {
 			tasklist->horz_width = tasklist->config.horz_width;
+			if (tasklist->config.horz_never_push)
+				clamp_size (tasklist, &tasklist->horz_width);
+			tasklist->horz_width -= DRAG_HANDLE_SIZE;
+		}
 		else
-			tasklist->horz_width = num_cols * curwidth + 4;
+			tasklist->horz_width = num_cols * curwidth;
 
 		tasklist_change_size (tasklist, FALSE, -1);
 
