@@ -1380,7 +1380,7 @@ static char
 	next_row(currow);
 	curfield=layout->first;
 	i=0;
-	while (!finished) {
+	while (!finished && *c) {
 		/* search item */
 		h=c;
 		if ((*c=='_' || *c=='=') && (c[1]==itemsep || c[1]=='\n')) {
