@@ -1,5 +1,6 @@
 #include <config.h>
 #include <string.h>
+#include <stdio.h>
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <gtk/gtk.h>
@@ -927,11 +928,13 @@ gnome_panel_applet_corba_init(AppletWidget *applet, const char *goad_id)
 		panel_client =
 			goad_server_activate_with_repo_id(NULL,
 							  "IDL:GNOME/Panel:1.0",
-							  0, NULL);
+							  GOAD_ACTIVATE_EXISTING_ONLY,
+							  NULL);
 
-		if(panel_client == CORBA_OBJECT_NIL) {
-			g_warning(_("Cannot activate a panel object"));
+		if (panel_client == CORBA_OBJECT_NIL) {
+			fprintf (stderr, _("The GNOME panel is not running."));
 			g_free (applet_servant);
+			exit (1);
 			return NULL;
 		}
 	}
