@@ -1016,19 +1016,19 @@ button_widget_up(ButtonWidget *button)
 static GdkPixbuf *
 make_hc_pixbuf(GdkPixbuf *pb)
 {
-	GdkPixbuf *new;
+	GdkPixbuf *newpb;
 	if(!pb)
 		return NULL;
 
-	new = gdk_pixbuf_new(gdk_pixbuf_get_colorspace(pb),
+	newpb = gdk_pixbuf_new(gdk_pixbuf_get_colorspace(pb),
 			     gdk_pixbuf_get_has_alpha(pb),
 			     gdk_pixbuf_get_bits_per_sample(pb),
 			     gdk_pixbuf_get_width(pb),
 			     gdk_pixbuf_get_height(pb));
-	do_colorshift(new, pb, 30);
-	/*do_saturate_darken (new, pb, (int)(1.00*255), (int)(1.15*255));*/
+	do_colorshift(newpb, pb, 30);
+	/*do_saturate_darken (newpb, pb, (int)(1.00*255), (int)(1.15*255));*/
 
-	return new;
+	return newpb;
 }
 
 
