@@ -9,6 +9,7 @@
 #include <config.h>
 #include <gtk/gtk.h>
 #include <gnome.h>
+#include <basep-widget.h>
 #include "panel-widget.h"
 #include "button-widget.h"
 #include "panel-util.h"
@@ -987,6 +988,10 @@ panel_widget_setup_translucent_background (PanelWidget *panel)
 	GdkPixbuf *background_shaded = NULL;
 	GdkWindow *window = gtk_widget_get_parent_window (GTK_WIDGET (panel));
 
+	BasePWidget *basep = BASEP_WIDGET(panel->panel_parent);
+  	
+	if (basep->state != BASEP_SHOWN || basep->state == BASEP_MOVING)
+		return;
 	if (desktop_pixmap && window != NULL) {
 		background = gdk_pixbuf_get_from_drawable (NULL,
 				desktop_pixmap, 
